==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/item/PackedSnowBallItem.java <==
package com.github.thedeathlycow.frostiful.item;

import com.github.thedeathlycow.frostiful.entity.PackedSnowballEntity;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_9463;

public class PackedSnowBallItem extends class_1792 implements class_9463 {

    public PackedSnowBallItem(class_1792.class_1793 settings) {
        super(settings);
    }

    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        world.method_43128(
                null,
                user.method_23317(), user.method_23318(), user.method_23321(),
                class_3417.field_14873, class_3419.field_15254,
                0.5f, 0.4f / (world.method_8409().method_43057() * 0.4f + 0.8f)
        );

        if (!world.field_9236) {
            PackedSnowballEntity snowball = new PackedSnowballEntity(world, user);
            snowball.method_16940(itemStack);
            snowball.method_24919(user, user.method_36455(), user.method_36454(), 0.0f, 1.5f, 1.0f);
            world.method_8649(snowball);
        }

        user.method_7259(class_3468.field_15372.method_14956(this));
        itemStack.method_57008(1, user);

        return class_1271.method_29237(itemStack, world.method_8608());
    }

    @Override
    public class_1676 method_58648(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        PackedSnowballEntity packedSnowball = new PackedSnowballEntity(world, pos.method_10216(), pos.method_10214(), pos.method_10215());
        packedSnowball.method_16940(stack);
        return packedSnowball;
    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/item/PackedSnowBallItem.java <==
package com.github.thedeathlycow.frostiful.item;

import com.github.thedeathlycow.frostiful.entity.PackedSnowballEntity;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_9463;

public class PackedSnowBallItem extends class_1792 implements class_9463 {

    public PackedSnowBallItem(class_1792.class_1793 settings) {
        super(settings);
    }

    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        world.method_43128(
                null,
                user.method_23317(), user.method_23318(), user.method_23321(),
                class_3417.field_14873, class_3419.field_15254,
                0.5f, 0.4f / (world.method_8409().method_43057() * 0.4f + 0.8f)
        );

        if (!world.field_9236) {
            PackedSnowballEntity snowball = new PackedSnowballEntity(world, user, itemStack);
            snowball.method_16940(itemStack);
            snowball.method_24919(user, user.method_36455(), user.method_36454(), 0.0f, 1.5f, 1.0f);
            world.method_8649(snowball);
        }

        user.method_7259(class_3468.field_15372.method_14956(this));
        itemStack.method_57008(1, user);

        return class_1269.field_5812;
    }

    @Override
    public class_1676 method_58648(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        PackedSnowballEntity packedSnowball = new PackedSnowballEntity(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), stack);
        packedSnowball.method_16940(stack);
        return packedSnowball;
    }
}
